.. parametrization_clean documentation master file, created by
   sphinx-quickstart on Thu May  7 11:12:25 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to parametrization_clean's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   readme
   installation
   usage
   contributing
   authors
   history



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
